/* eslint-disable prettier/prettier */
import React, {Component} from 'react';
import { View,Image,Text,NativeEventEmitter } from 'react-native';
import JitsiManager from '../lib/JitsiManager';
import { connect } from 'react-redux';
import ButtonBar from './ButtonBar';
import MainVideo from './MainVideo';
import ThumbnailView from './ThumbnailView';
import Logger from '../lib/Logger';
import AudioMode from '../AudioMode';
var username,userAvatar;

class ConferenceScreen extends Component{
    
    constructor(props){
        super(props);
        if(JitsiManager.isInitiator){
            username = JitsiManager.userObject.name;
            userAvatar = JitsiManager.userObject.avatar;
        }else{
            username = JitsiManager.receiverObject.name;
            userAvatar = JitsiManager.receiverObject.avatar;
        }

        this.addEventListener = this.addEventListener.bind(this);

        this.state = {
            showConnectionState: true,
        }
    }

    componentDidMount(){
        this.props.init(this.props.room.toLowerCase());
        Logger.log("Default layout enabled ? ",this.props.enableDefaultLayout)
        JitsiManager.makeConnection();
        JitsiManager.addEventListener();
        this.props.createLocalTracks();
        this.addEventListener();
    }

    addEventListener(){
        this.eventListener = new NativeEventEmitter(AudioMode);
        this.eventListener.addListener('CallEvent',(type) =>{
            if(type.type == "onConnectionSuccess"){
                Logger.log("OnConnectionSuccess received")
                this.setState({
                    showConnectionState: false,
                }); 
            }
        });
    }

    renderConferenceScreen(enableDefaultLayout){
        return <View style={{ height: '100%', width: '100%', position: 'relative' }}>
                    <MainVideo />
                    <ThumbnailView />
                    { enableDefaultLayout ? <ButtonBar 
                                                hideAudioMuteButton = {this.props.hideAudioMuteButton}
                                                hideEndCallButton = {this.props.hideEndCallButton}
                                                hidePauseVideoButton = {this.props.hidePauseVideoButton}
                                                hideVideoSwitchButton = {this.props.hideVideoSwitchButton}
                                                hideAudioModeButton = {this.props.hideAudioModeButton}
                                            /> : null}

                </View>;
    }

    renderAudioConfrenceScreen(enableDefaultLayout){
        return <View style={{ height: '100%', width: '100%', position: 'relative', backgroundColor : '#000000', zIndex: 2 }}>
                   <View style={this.style.avatarContainer}>
                        <Image
                                style={this.style.avatar}
                                resizeMode={"cover"}
                                source={{uri: userAvatar}}
                        />
                        <Text style={this.style.callerName}>{username}</Text>
                    </View>

                    <View style={{width: '100%',bottom: 0 , position: 'absolute'}}>

                        { this.state.showConnectionState ? <Text style={{color: "#FFF", bottom:120,alignSelf:"center" }}>Connecting .... </Text> : null}

                        { enableDefaultLayout ? <ButtonBar 
                                                hideAudioMuteButton = {this.props.hideAudioMuteButton}
                                                hideEndCallButton = {this.props.hideEndCallButton}
                                                hidePauseVideoButton = {true}
                                                hideVideoSwitchButton = {true}
                                                hideAudioModeButton = {this.props.hideAudioModeButton}
                                            /> : null}
                    </View>
                </View>; 
    }

    render(){
        var enableDefaultLayout = this.props.enableDefaultLayout;
        var isAudioOnly = this.props.isAudioOnly || false;
        return(
            <View style={{ height: '100%', width: '100%' }}>
                { isAudioOnly ? this.renderAudioConfrenceScreen(enableDefaultLayout) : this.renderConferenceScreen(enableDefaultLayout) }
            </View>
        )
        
    }
    style = { 
        lt_container : { flexDirection: 'column-reverse', alignItems: 'flex-end', position: 'absolute', right: 0, bottom: 0 },
        button_container :{ 
            position: 'absolute', 
            bottom: 0,
            display:'flex', 
            width: '100%',
            height: 100,
            alignItems: 'center'
        },
        avatarContainer:{
            alignSelf:"center",
            margin:100,
            flexDirection:"column",
            justifyContent: 'center'
        },
        callerName: {
            width:"100%",
            color: "#FFF",
            fontSize: 25,
            fontWeight: 'bold',
            alignSelf:'center',
        },
        avatar: {
            height: 200,
            width: 200,
            borderRadius: 500,
        }
    };
}

function mapStateToProps (state) {
    return {
      remoteTracks: state.tracks.remoteTracks
    }
}
  
function mapDispatchToProps (dispatch) {
    return {
        init: (room) => JitsiManager.init(room),
        createLocalTracks: () => JitsiManager.createLocalTracks(dispatch)
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(ConferenceScreen)